@@ -13,6 +13,7 @@
 #' @param d The depth for which accumulation rates need to be returned.
 #' @param set Detailed information of the current run, stored within this session's memory as variable \code{info}.
 #' @param cmyr Accumulation rates can be calculated in cm/year or year/cm. By default \code{cmyr=FALSE} and accumulation rates are calculated in year per cm.
+#' @param na.rm Remove NA entries. These are NOT removed by default, so that always the same amount of iterations is returned.
 #' @author Maarten Blaauw, J. Andres Christen
 #' @return all MCMC estimates of accumulation rate of the chosen depth.
 #' @examples
@@ -25,12 +26,15 @@
 #'   mean(d20)
 #' }
 #' @export
-accrate.depth <- function(d, set=get('info'), cmyr=FALSE) {
+accrate.depth <- function(d, set=get('info'), cmyr=FALSE, na.rm=FALSE) {
   accs.elbows <- set$output[,2:(set$K+1)]
   if(min(set$elbows) <= d && max(set$elbows) >= d)
     accs <- unlist(accs.elbows[max(which(set$elbows <= d))]) else
   #  accs <- set$output[,1+min(which(set$elbows >= d))] else # was 1 + max(which(set$elbows < d))...
       accs <- NA
+  accs <- as.numeric(accs)
+  if(na.rm)
+    accs <- accs[!is.na(accs)]
   if(cmyr) 1/accs else accs
 }
 
@@ -51,6 +55,7 @@ accrate.depth <- function(d, set=get('info'), cmyr=FALSE) {
 #' @param ages The ages of the age-depth model. Not provided by default, but can be provided to speed things up if the function is called repeatedly
 #' @param BCAD The calendar scale of graphs and age output-files is in \code{cal BP} by default, but can be changed to BC/AD using \code{BCAD=TRUE}.
 #' @param silent Warn when ages are outside the core's range. Default \code{silent=TRUE}.
+#' @param na.rm Remove NA entries. These are NOT removed by default, so that always the same amount of iterations is returned.
 #' @author Maarten Blaauw, J. Andres Christen
 #' @return all MCMC estimates of accumulation rate of the chosen age.
 #' @examples
@@ -62,12 +67,9 @@ accrate.depth <- function(d, set=get('info'), cmyr=FALSE) {
 #'   hist(accrate.a5000)
 #' }
 #' @export
-accrate.age <- function(age, set=get('info'), cmyr=FALSE, ages=c(), BCAD=set$BCAD, silent=TRUE) {
-  if(length(ages) == 0) {
-    ages <- array(0, dim=c(nrow(set$output), length(set$elbows)))
-    for(i in 1:ncol(ages))
-      ages[,i] <- Bacon.Age.d(set$elbows[i], BCAD=BCAD)
-  }
+accrate.age <- function(age, set=get('info'), cmyr=FALSE, ages=c(), BCAD=set$BCAD, silent=TRUE, na.rm=FALSE) {
+  if(length(ages) == 0)
+    ages <- sapply(set$elbows, Bacon.Age.d)
 
   if(!silent)
     if(age < min(ages) || age > max(ages))
@@ -81,8 +83,11 @@ accrate.age <- function(age, set=get('info'), cmyr=FALSE, ages=c(), BCAD=set$BCA
       these <- (ages[,i-1] > age) * (ages[,i] < age) else
         these <- (ages[,i-1] < age) * (ages[,i] > age)
     if(sum(these) > 0) # age lies within these age-model iterations
-      accs <- c(accs, set$output[which(these>0),i]) # was i+1
+      #accs <- c(accs, set$output[which(these>0),i]) # was i+1
+      accs[which(these>0)] <- set$output[which(these>0),i] # Jan 2023
   }
+  if(na.rm)
+    accs <- accs[!is.na(accs)]
   if(cmyr)
     accs <- 1/accs
   return(accs)
